package com.ruoyi.branch.service.impl;

import java.util.List;

import com.ruoyi.common.annotation.DataScope;
import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.branch.mapper.TBranchManageMapper;
import com.ruoyi.branch.domain.TBranchManage;
import com.ruoyi.branch.service.ITBranchManageService;

/**
 * 支部党课学习资料管理Service业务层处理
 *
 * @author ruoyi
 * @date 2023-07-14
 */
@Service
public class TBranchManageServiceImpl implements ITBranchManageService
{
    @Autowired
    private TBranchManageMapper tBranchManageMapper;

    /**
     * 查询支部党课学习资料管理
     *
     * @param manageId 支部党课学习资料管理主键
     * @return 支部党课学习资料管理
     */
    @Override
    public TBranchManage selectTBranchManageByManageId(Long manageId)
    {
        return tBranchManageMapper.selectTBranchManageByManageId(manageId);
    }

    /**
     * 查询支部党课学习资料管理列表
     *
     * @param tBranchManage 支部党课学习资料管理
     * @return 支部党课学习资料管理
     */
    @Override
    @DataScope(deptAlias = "d", userAlias = "u")
    public List<TBranchManage> selectTBranchManageList(TBranchManage tBranchManage)
    {
        return tBranchManageMapper.selectTBranchManageList(tBranchManage);
    }

    /**
     * 新增支部党课学习资料管理
     *
     * @param tBranchManage 支部党课学习资料管理
     * @return 结果
     */
    @Override
    public int insertTBranchManage(TBranchManage tBranchManage)
    {
        tBranchManage.setCreateTime(DateUtils.getNowDate());
        return tBranchManageMapper.insertTBranchManage(tBranchManage);
    }

    /**
     * 修改支部党课学习资料管理
     *
     * @param tBranchManage 支部党课学习资料管理
     * @return 结果
     */
    @Override
    public int updateTBranchManage(TBranchManage tBranchManage)
    {
        tBranchManage.setUpdateTime(DateUtils.getNowDate());
        return tBranchManageMapper.updateTBranchManage(tBranchManage);
    }

    /**
     * 批量删除支部党课学习资料管理
     *
     * @param manageIds 需要删除的支部党课学习资料管理主键
     * @return 结果
     */
    @Override
    public int deleteTBranchManageByManageIds(Long[] manageIds)
    {
        return tBranchManageMapper.deleteTBranchManageByManageIds(manageIds);
    }

    /**
     * 删除支部党课学习资料管理信息
     *
     * @param manageId 支部党课学习资料管理主键
     * @return 结果
     */
    @Override
    public int deleteTBranchManageByManageId(Long manageId)
    {
        return tBranchManageMapper.deleteTBranchManageByManageId(manageId);
    }
}
